@@ -1593,8 +1593,9 @@ public:
     }
 
     if (data.HasSpeed()) {
+      // We expect m/s here
       if (data.GetSpeed()>=1/3.6) {
-        speed->Set(DoubleToString(data.GetSpeed()*3.6)+L"km/h");
+        speed->Set(DoubleToString(data.GetSpeed()*3600.0/1000)+L"km/h");
       }
       else {
         speed->Set(DoubleToString(data.GetSpeed())+L"m/s");
@@ -1796,7 +1797,7 @@ static void cb(struct gps_data_t* data, char * buf, size_t len, int level)
   }
 
   if ((data->set & SPEED_SET) && !isnan(data->fix.speed)) {
-    gpsData.SetSpeed(data->fix.speed/3.6);
+    gpsData.SetSpeed(data->fix.speed); // m/s
   }
 
   if ((data->set & TRACK_SET) && !isnan(data->fix.track)) {
@@ -1861,7 +1862,7 @@ static void gps_location_changed(LocationGPSDevice *device, gpointer userdata)
     gpsData.SetAltitude(fix->altitude);
   }
   if (fix->fields & LOCATION_GPS_DEVICE_SPEED_SET && !isnan(fix->speed)) {
-    gpsData.SetSpeed(fix->speed);
+    gpsData.SetSpeed(fix->speed*1000.0/3600); // km/h => m/s
   }
   if (fix->fields & LOCATION_GPS_DEVICE_TRACK_SET && !isnan(fix->track)) {
     gpsData.SetTrack(fix->track);
